@@ -69,6 +69,58 @@ static void _gnc_sx_instance_event_handler(QofInstance *ent, QofEventId event_ty
 
 /* ------------------------------------------------------------ */
 
+static gboolean
+scrub_sx_split_numeric (kvp_frame *kvp, const char *debcred)
+{
+    const gboolean is_credit = g_strcmp0 (debcred, "credit") == 0;
+    const char *formula = is_credit ?
+        GNC_SX_CREDIT_FORMULA : GNC_SX_DEBIT_FORMULA;
+    const char *numeric = is_credit ?
+        GNC_SX_CREDIT_NUMERIC : GNC_SX_DEBIT_NUMERIC;
+    const KvpValue *val = kvp_frame_get_slot_path (kvp,
+                                                   GNC_SX_ID, formula,
+                                                   NULL);
+    const KvpValue *num = kvp_frame_get_slot_path (kvp,
+                                                   GNC_SX_ID, numeric,
+                                                   NULL);
+    const char *value = kvp_value_get_string (val);
+    GHashTable *parser_vars = g_hash_table_new (g_str_hash, g_str_equal);
+    char *error_loc;
+    gnc_numeric amount = gnc_numeric_zero ();
+    const gboolean parse_result =
+        gnc_exp_parser_parse_separate_vars (value, &amount,
+                                            &error_loc, parser_vars);
+    if (!parse_result || g_hash_table_size (parser_vars) != 0)
+        amount = gnc_numeric_zero ();
+    g_hash_table_unref (parser_vars);
+    if (gnc_numeric_eq (amount, kvp_value_get_numeric (num)))
+        return FALSE;
+    kvp_frame_set_slot_path (kvp, kvp_value_new_numeric (amount),
+                             GNC_SX_ID,
+                             numeric,
+                             NULL);
+    return TRUE;
+}
+
+/* Fixes error in pre-2.6.16 where the numeric slot wouldn't get changed if the
+ * formula slot was edited.
+ */
+void
+gnc_sx_scrub_split_numerics (gpointer psplit, gpointer puser)
+{
+    Split *split = GNC_SPLIT (psplit);
+    kvp_frame *kvp = xaccSplitGetSlots (split);
+    Transaction *trans = xaccSplitGetParent (split);
+    gboolean changed;
+    xaccTransBeginEdit (trans);
+    changed = scrub_sx_split_numeric (kvp, "credit") +
+        scrub_sx_split_numeric (kvp, "debit");
+    if (!changed)
+        xaccTransRollbackEdit (trans);
+    else
+        xaccTransCommitEdit (trans);
+}
+
 static void
 _sx_var_to_raw_numeric(gchar *name, GncSxVariable *var, GHashTable *parser_var_hash)
 {
@@ -249,18 +301,16 @@ _get_vars_helper(Transaction *txn, void *var_hash_data)
             ! gnc_commodity_equal(split_cmdty, first_cmdty))
         {
             GncSxVariable *var;
-            GString *var_name;
+            gchar *var_name;
             const gchar *split_mnemonic, *first_mnemonic;
 
-            var_name = g_string_sized_new(16);
             split_mnemonic = gnc_commodity_get_mnemonic(split_cmdty);
             first_mnemonic = gnc_commodity_get_mnemonic(first_cmdty);
-            g_string_printf(var_name, "%s -> %s",
+            var_name = g_strdup_printf ("%s -> %s",
                             split_mnemonic ? split_mnemonic : "(null)",
                             first_mnemonic ? first_mnemonic : "(null)");
-            var = gnc_sx_variable_new(g_strdup(var_name->str));
+            var = gnc_sx_variable_new(var_name);
             g_hash_table_insert(var_hash, g_strdup(var->name), var);
-            g_string_free(var_name, TRUE);
         }
 
     }
@@ -956,16 +1006,15 @@ _get_template_split_account(const SchedXaction* sx, const Split *template_split,
     if (*split_acct == NULL)
     {
         char guid_str[GUID_ENCODING_LENGTH+1];
-        GString *err;
+        gchar* err;
         guid_to_string_buff((const GncGUID*)acct_guid, guid_str);
-        err = g_string_new("");
-        g_string_printf(err, "Unknown account for guid [%s], cancelling SX [%s] creation.",
+        err = g_strdup_printf ("Unknown account for guid [%s], cancelling SX [%s] creation.",
                         guid_str, xaccSchedXactionGetName(sx));
-        g_critical("%s", err->str);
+        g_critical("%s", err);
         if (creation_errors != NULL)
             *creation_errors = g_list_append(*creation_errors, err);
         else
-            g_string_free(err, TRUE);
+            g_free(err);
         return FALSE;
     }
 
@@ -1016,18 +1065,17 @@ _get_sx_formula_value(const SchedXaction* sx, const Split *template_split, gnc_n
                                                 &parseErrorLoc,
                                                 parser_vars))
         {
-            GString *err = g_string_new("");
-            g_string_printf(err, "Error parsing SX [%s] key [%s]=formula [%s] at [%s]: %s",
+            gchar *err = g_strdup_printf ("Error parsing SX [%s] key [%s]=formula [%s] at [%s]: %s",
                             xaccSchedXactionGetName(sx),
                             formula_key,
                             formula_str,
                             parseErrorLoc,
                             gnc_exp_parser_error_string());
-            g_critical("%s", err->str);
+            g_critical ("%s", err);
             if (creation_errors != NULL)
                 *creation_errors = g_list_append(*creation_errors, err);
             else
-                g_string_free(err, TRUE);
+                g_free (err);
         }
 
         if (parser_vars != NULL)
@@ -1075,15 +1123,14 @@ split_apply_formulas (const Split *split, SxTxnCreationData* creation_data)
     gncn_error = gnc_numeric_check(final);
     if (gncn_error != GNC_ERROR_OK)
     {
-        GString *err = g_string_new("");
-        g_string_printf(err, "error %d in SX [%s] final gnc_numeric value, using 0 instead",
+        gchar *err = g_strdup_printf ("error %d in SX [%s] final gnc_numeric value, using 0 instead",
                         gncn_error, xaccSchedXactionGetName(sx));
-        g_critical("%s", err->str);
+        g_critical("%s", err);
         if (creation_data->creation_errors != NULL)
             *creation_data->creation_errors =
                 g_list_append(*creation_data->creation_errors, err);
         else
-            g_string_free(err, TRUE);
+            g_free (err);
         final = gnc_numeric_zero();
     }
     return final;
@@ -1094,12 +1141,12 @@ split_apply_exchange_rate (Split *split, GHashTable *bindings,
                            gnc_commodity *first_cmdty,
                            gnc_commodity *split_cmdty, gnc_numeric *final)
 {
-    GString *exchange_rate_var_name = g_string_sized_new(16);
+    gchar *exchange_rate_var_name;
     GncSxVariable *exchange_rate_var;
     gnc_numeric amt;
     gnc_numeric exchange_rate = gnc_numeric_create (1, 1);
 
-    g_string_printf(exchange_rate_var_name, "%s -> %s",
+    exchange_rate_var_name = g_strdup_printf ("%s -> %s",
                     gnc_commodity_get_mnemonic(first_cmdty),
                     gnc_commodity_get_mnemonic(split_cmdty));
 
@@ -1108,14 +1155,14 @@ split_apply_exchange_rate (Split *split, GHashTable *bindings,
 
     exchange_rate_var =
         (GncSxVariable*)g_hash_table_lookup(bindings,
-                                            exchange_rate_var_name->str);
+                                            exchange_rate_var_name);
 
     if (exchange_rate_var != NULL)
     {
         exchange_rate = exchange_rate_var->value;
         g_debug("exchange_rate is %s", gnc_numeric_to_string (exchange_rate));
     }
-    g_string_free(exchange_rate_var_name, TRUE);
+    g_free (exchange_rate_var_name);
 
     if (!gnc_commodity_is_currency (split_cmdty))
         amt = gnc_numeric_div(*final, exchange_rate,
@@ -1707,30 +1754,28 @@ create_cashflow_helper(Transaction *template_txn, void *user_data)
             gncn_error = gnc_numeric_check(final);
             if (gncn_error != GNC_ERROR_OK)
             {
-                GString *err = g_string_new("");
-                g_string_printf(err, "error %d in SX [%s] final gnc_numeric value, using 0 instead",
+                gchar* err = g_strdup_printf ("error %d in SX [%s] final gnc_numeric value, using 0 instead",
                                 gncn_error, xaccSchedXactionGetName(creation_data->sx));
-                g_critical("%s", err->str);
+                g_critical("%s", err);
                 if (creation_data->creation_errors != NULL)
                     *creation_data->creation_errors = g_list_append(*creation_data->creation_errors, err);
                 else
-                    g_string_free(err, TRUE);
+                    g_free (err);
                 final = gnc_numeric_zero();
             }
 
             /* Print error message if we would have needed an exchange rate */
             if (! gnc_commodity_equal(split_cmdty, first_cmdty))
             {
-                GString *err = g_string_new("");
-                g_string_printf(err, "No exchange rate available in SX [%s] for %s -> %s, value is zero",
+                gchar* err = g_strdup_printf ("No exchange rate available in SX [%s] for %s -> %s, value is zero",
                                 xaccSchedXactionGetName(creation_data->sx),
                                 gnc_commodity_get_mnemonic(split_cmdty),
                                 gnc_commodity_get_mnemonic(first_cmdty));
-                g_critical("%s", err->str);
+                g_critical("%s", err);
                 if (creation_data->creation_errors != NULL)
                     *creation_data->creation_errors = g_list_append(*creation_data->creation_errors, err);
                 else
-                    g_string_free(err, TRUE);
+                    g_free(err);
                 final = gnc_numeric_zero();
             }
 
