@@ -56,13 +56,13 @@ static QofLogModule log_module = G_LOG_DOMAIN;
 static GncSqlColumnTableEntry col_table[] =
 {
     { "guid",        CT_GUID,     0,                 COL_NNUL | COL_PKEY, "guid" },
-    { "id",          CT_STRING,   MAX_ID_LEN,        COL_NNUL,          NULL, ORDER_ID },
-    { "notes",       CT_STRING,   MAX_NOTES_LEN,     COL_NNUL,          "notes" },
-    { "reference",   CT_STRING,   MAX_REFERENCE_LEN, COL_NNUL,          NULL, ORDER_REFERENCE },
-    { "active",      CT_BOOLEAN,  0,                 COL_NNUL,          NULL, QOF_PARAM_ACTIVE },
-    { "date_opened", CT_TIMESPEC, 0,                 COL_NNUL,          NULL, ORDER_OPENED },
-    { "date_closed", CT_TIMESPEC, 0,                 COL_NNUL,          NULL, ORDER_CLOSED },
-    { "owner",       CT_OWNERREF, 0,                 COL_NNUL,          NULL, ORDER_OWNER },
+    { "id",          CT_STRING,   MAX_ID_LEN,        COL_NNUL,            "id" },
+    { "notes",       CT_STRING,   MAX_NOTES_LEN,     COL_NNUL,            "notes" },
+    { "reference",   CT_STRING,   MAX_REFERENCE_LEN, COL_NNUL,            "reference" },
+    { "active",      CT_BOOLEAN,  0,                 COL_NNUL,            "order" },
+    { "date_opened", CT_TIMESPEC, 0,                 COL_NNUL,            "date-opened" },
+    { "date_closed", CT_TIMESPEC, 0,                 COL_NNUL,            "date-closed" },
+    { "owner",       CT_OWNERREF, 0,                 COL_NNUL,            NULL, ORDER_OWNER },
     { NULL },
 };
 
@@ -76,10 +76,10 @@ load_single_order( GncSqlBackend* be, GncSqlRow* row )
     g_return_val_if_fail( row != NULL, NULL );
 
     guid = gnc_sql_load_guid( be, row );
-    pOrder = gncOrderLookup( be->primary_book, guid );
+    pOrder = gncOrderLookup( be->book, guid );
     if ( pOrder == NULL )
     {
-        pOrder = gncOrderCreate( be->primary_book );
+        pOrder = gncOrderCreate( be->book );
     }
     gnc_sql_load_object( be, row, GNC_ID_ORDER, pOrder, col_table );
     qof_instance_mark_clean( QOF_INSTANCE(pOrder) );
@@ -92,12 +92,9 @@ load_all_orders( GncSqlBackend* be )
 {
     GncSqlStatement* stmt;
     GncSqlResult* result;
-    QofBook* pBook;
 
     g_return_if_fail( be != NULL );
 
-    pBook = be->primary_book;
-
     stmt = gnc_sql_create_select_statement( be, TABLE_NAME );
     result = gnc_sql_execute_select_statement( be, stmt );
     gnc_sql_statement_dispose( stmt );
@@ -194,7 +191,7 @@ write_orders( GncSqlBackend* be )
 
     data.be = be;
     data.is_ok = TRUE;
-    qof_object_foreach( GNC_ID_ORDER, be->primary_book, write_single_order, &data );
+    qof_object_foreach( GNC_ID_ORDER, be->book, write_single_order, &data );
 
     return data.is_ok;
 }
@@ -218,7 +215,7 @@ load_order_guid( const GncSqlBackend* be, GncSqlRow* row,
     if ( val != NULL && G_VALUE_HOLDS_STRING( val ) && g_value_get_string( val ) != NULL )
     {
         string_to_guid( g_value_get_string( val ), &guid );
-        order = gncOrderLookup( be->primary_book, &guid );
+        order = gncOrderLookup( be->book, &guid );
         if ( order != NULL )
         {
             if ( table_row->gobj_param_name != NULL )
