@@ -56,13 +56,16 @@ void gnc_gtk_add_rc_file (void);
  */
 void gnc_gnome_help (const char *file_name,
                      const char *anchor);
+/** Launch the default gnome browser and open the provided URI.
+ */
+void gnc_launch_assoc (const char *uri);
 
 /** Set the help callback to 'gnc_book_options_help_cb' to open a help browser
  *  and point it to the Book Options link in the Help file.
  */
 void gnc_options_dialog_set_book_options_help_cb (GNCOptionWin *win);
  
-/** Set the intial values of new book options to values specified in user
+/** Set the initial values of new book options to values specified in user
  *  preferences.
  */
 void gnc_options_dialog_set_new_book_option_values (GNCOptionDB *odb);
