@@ -1,26 +1,26 @@
-/********************************************************************\
- * gnc-tree-view-account.h -- GtkTreeView implementation to display *
- *                            accounts in a GtkTreeView.            *
+/**********************************************************************\
+ * gnc-tree-view-account.h -- GtkTreeView implementation to display   *
+ *                            accounts in a GtkTreeView.              *
  * Copyright (C) 2003,2005,2006 David Hampton <hampton@employees.org> *
- *                                                                  *
- * This program is free software; you can redistribute it and/or    *
- * modify it under the terms of the GNU General Public License as   *
- * published by the Free Software Foundation; either version 2 of   *
- * the License, or (at your option) any later version.              *
- *                                                                  *
- * This program is distributed in the hope that it will be useful,  *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the    *
- * GNU General Public License for more details.                     *
- *                                                                  *
- * You should have received a copy of the GNU General Public License*
- * along with this program; if not, contact:                        *
- *                                                                  *
- * Free Software Foundation           Voice:  +1-617-542-5942       *
- * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
- * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
- *                                                                  *
-\********************************************************************/
+ *                                                                    *
+ * This program is free software; you can redistribute it and/or      *
+ * modify it under the terms of the GNU General Public License as     *
+ * published by the Free Software Foundation; either version 2 of     *
+ * the License, or (at your option) any later version.                *
+ *                                                                    *
+ * This program is distributed in the hope that it will be useful,    *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of     *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the      *
+ * GNU General Public License for more details.                       *
+ *                                                                    *
+ * You should have received a copy of the GNU General Public License  *
+ * along with this program; if not, contact:                          *
+ *                                                                    *
+ * Free Software Foundation           Voice:  +1-617-542-5942         *
+ * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652         *
+ * Boston, MA  02110-1301,  USA       gnu@gnu.org                     *
+ *                                                                    *
+\**********************************************************************/
 
 /** @addtogroup GUI
     @{ */
@@ -64,8 +64,8 @@ struct AccountViewInfo_s
 
 typedef struct
 {
-    GncTreeView gnc_tree_view;
-    int stamp;
+    GncTreeView   gnc_tree_view;
+    int           stamp;
 } GncTreeViewAccount;
 
 typedef struct
@@ -75,15 +75,15 @@ typedef struct
 
 typedef	struct
 {
-    GtkWidget    *dialog;
-    GtkTreeModel *model;
+    GtkWidget           *dialog;
+    GtkTreeModel        *model;
     GncTreeViewAccount  *tree_view;
-    guint32      visible_types;
-    guint32      original_visible_types;
-    gboolean     show_hidden;
-    gboolean     original_show_hidden;
-    gboolean     show_zero_total;
-    gboolean     original_show_zero_total;
+    guint32              visible_types;
+    guint32              original_visible_types;
+    gboolean             show_hidden;
+    gboolean             original_show_hidden;
+    gboolean             show_zero_total;
+    gboolean             original_show_zero_total;
 } AccountFilterDialog;
 
 void account_filter_dialog_create(AccountFilterDialog *fd,
@@ -285,27 +285,7 @@ typedef gboolean (*gnc_tree_view_account_filter_func)(Account *account, gpointer
 void gnc_tree_view_account_set_filter (GncTreeViewAccount *account_view,
                                        gnc_tree_view_account_filter_func func,
                                        gpointer data,
-                                       GtkFunction destroy);
-
-/*  This is a convenient filter function for use with
- *  gnc_tree_view_account_set_filter() and the functions in
- *  gnc-tree-model-account-types.h.  If you have some view that is
- *  backed by the "account types" tree model, you can get a guint32
- *  from that view's tree selection.  Then, you can use that account
- *  type selection as a filter for the account tree view.  For
- *  example:
- *
- *  guint sel_mask;
- *
- *  sel_mask = gnc_tree_model_account_types_get_selection(view);
- *
- *  gnc_tree_view_account_set_filter(account_view,
- *    gnc_tree_view_account_filter_by_type_selection,
- *    GUINT_TO_POINTER(sel_mask), NULL);
- *
- */
-gboolean gnc_tree_view_account_filter_by_type_selection(
-    Account* acct, gpointer data);
+                                       GSourceFunc destroy);
 
 /*  This is a convenient filter function for use with
  *  gnc_tree_view_account_set_filter() and the functions in
