@@ -28,7 +28,7 @@
 
 typedef struct _print_check_dialog PrintCheckDialog;
 
-void gnc_ui_print_check_dialog_create(GncPluginPageRegister *plugin_page,
+void gnc_ui_print_check_dialog_create(GtkWidget *parent,
                                       GList *splits);
 
 #endif
