@@ -31,25 +31,34 @@
 #include "gnc-component-manager.h"
 #include "gnc-plugin-register.h"
 #include "gnc-plugin-page-register.h"
+#include "gnc-prefs.h"
 
 
 static void gnc_plugin_register_class_init (GncPluginRegisterClass *klass);
 static void gnc_plugin_register_init (GncPluginRegister *plugin);
 static void gnc_plugin_register_finalize (GObject *object);
 
+static void gnc_plugin_register_add_to_window (GncPlugin *plugin, GncMainWindow *window, GQuark type);
+static void gnc_plugin_register_remove_from_window (GncPlugin *plugin, GncMainWindow *window, GQuark type);
+
 /* Command callbacks */
 static void gnc_plugin_register_cmd_general_ledger (GtkAction *action, GncMainWindowActionData *data);
 
 #define PLUGIN_ACTIONS_NAME "gnc-plugin-register-actions"
 #define PLUGIN_UI_FILENAME  "gnc-plugin-register-ui.xml"
-#define GCONF_REGISTER_SECTION "general/register"
 
 static GtkActionEntry gnc_plugin_actions [] =
 {
     {
+#ifdef REGISTER2_ENABLED
         "ToolsGeneralLedgerAction", NULL, N_("Old St_yle General Ledger"), NULL,
         N_("Open an old style general ledger window"),
         G_CALLBACK (gnc_plugin_register_cmd_general_ledger)
+#else
+        "ToolsGeneralLedgerAction", NULL, N_("_General Ledger"), NULL,
+        N_("Open general ledger window"),
+        G_CALLBACK (gnc_plugin_register_cmd_general_ledger)
+#endif
     },
 };
 static guint gnc_plugin_n_actions = G_N_ELEMENTS (gnc_plugin_actions);
@@ -70,23 +79,19 @@ static QofLogModule log_module = GNC_MOD_GUI;
  ************************************************************/
 
 /** This function is called whenever an entry in the general register
- *  section of gconf is changed.  It does nothing more than kick off a
+ *  preferences group is changed.  It does nothing more than kick off a
  *  gui refresh which should be delivered to any open register page.
- *  The register pages will then reread their settings from gconf and
+ *  The register pages will then reread their preferences and
  *  update the screen.
  *
- *  @client Unused.
+ *  @prefs Unused.
  *
- *  @cnxn_id Unused.
- *
- *  @entry Unused.
+ *  @pref Unused.
  *
  *  @user_data Unused.
  */
 static void
-gnc_plugin_register_gconf_changed (GConfClient *client,
-                                   guint cnxn_id,
-                                   GConfEntry *entry,
+gnc_plugin_register_pref_changed (gpointer prefs, gchar *pref,
                                    gpointer user_data)
 {
     ENTER("");
@@ -154,15 +159,17 @@ gnc_plugin_register_class_init (GncPluginRegisterClass *klass)
     /* plugin info */
     plugin_class->plugin_name  = GNC_PLUGIN_REGISTER_NAME;
 
+    /* function overrides */
+    plugin_class->add_to_window = gnc_plugin_register_add_to_window;
+    plugin_class->remove_from_window =
+        gnc_plugin_register_remove_from_window;
+
     /* widget addition/removal */
     plugin_class->actions_name = PLUGIN_ACTIONS_NAME;
     plugin_class->actions      = gnc_plugin_actions;
     plugin_class->n_actions    = gnc_plugin_n_actions;
     plugin_class->ui_filename  = PLUGIN_UI_FILENAME;
 
-    plugin_class->gconf_section = GCONF_REGISTER_SECTION;
-    plugin_class->gconf_notifications = gnc_plugin_register_gconf_changed;
-
     g_type_class_add_private(klass, sizeof(GncPluginRegisterPrivate));
 }
 
@@ -179,6 +186,55 @@ gnc_plugin_register_finalize (GObject *object)
     G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
+/************************************************************
+ *              Plugin Function Implementation              *
+ ************************************************************/
+
+/** Initialize the registeru for a window.  This function is
+ *  called as part of the initialization of a window, after all the
+ *  plugin menu items have been added to the menu structure.  Its job
+ *  is to correctly initialize the register.  It does this by
+ *  installing a function that listens for preference changes. Each
+ *  time a preference changes, it kicks off a gui refresh.
+ *
+ *  @param plugin A pointer to the gnc-plugin object responsible for
+ *  adding/removing the register.
+ *
+ *  @param window A pointer to the gnc-main-window that is being initialized.
+ *
+ *  @param type Unused
+ */
+static void
+gnc_plugin_register_add_to_window (GncPlugin *plugin,
+                                   GncMainWindow *window,
+                                   GQuark type)
+{
+    gnc_prefs_register_cb (GNC_PREFS_GROUP_GENERAL_REGISTER, NULL,
+                           gnc_plugin_register_pref_changed, window);
+}
+
+
+/** Finalize the register for this window.  This function is
+ *  called as part of the destruction of a window.
+ *
+ *  @param plugin A pointer to the gnc-plugin object responsible for
+ *  adding/removing the register.  It stops listening for
+ *  changes in the register preferences.
+ *
+ *  @param window A pointer the gnc-main-window that is being destroyed.
+ *
+ *  @param type Unused
+ */
+static void
+gnc_plugin_register_remove_from_window (GncPlugin *plugin,
+                                        GncMainWindow *window,
+                                        GQuark type)
+{
+    gnc_prefs_remove_cb_by_func (GNC_PREFS_GROUP_GENERAL_REGISTER, NULL,
+                                 gnc_plugin_register_pref_changed, window);
+}
+
+
 /************************************************************
  *                    Command Callbacks                     *
  ************************************************************/
