@@ -113,7 +113,9 @@ struct _GNCSplitRegClass
     void (*help_changed_cb) ( GNCSplitReg *w, gpointer user_data );
     void (*include_date_cb) ( GNCSplitReg *w, time64 date, gpointer user_data );
 };
-
+/* Something somewhere sets these to silly values and causes problems */
+#undef DELETE
+#undef DUPLICATE
 typedef enum
 {
     ENTER,
