@@ -42,6 +42,7 @@
 #include <webkit/webkit.h>
 
 #include "Account.h"
+#include "gnc-prefs.h"
 #include "gnc-gui-query.h"
 #include "gnc-engine.h"
 #include "gnc-html.h"
@@ -81,6 +82,7 @@ static char error_404_title[] = N_("Not found");
 static char error_404_body[] = N_("The specified URL could not be loaded.");
 
 #define BASE_URI_NAME "base-uri"
+#define GNC_PREF_RPT_DFLT_ZOOM "default-zoom"
 
 static WebKitNavigationResponse webkit_navigation_requested_cb(
     WebKitWebView* web_view,
@@ -110,6 +112,7 @@ static gboolean impl_webkit_export_to_file( GncHtml* self, const gchar* filepath
 static void impl_webkit_print( GncHtml* self, const gchar* jobname, gboolean export_pdf );
 static void impl_webkit_cancel( GncHtml* self );
 static void impl_webkit_set_parent( GncHtml* self, GtkWindow* parent );
+static void impl_webkit_default_zoom_changed(gpointer prefs, gchar *pref, gpointer user_data);
 
 static void
 gnc_html_webkit_init( GncHtmlWebkit* self )
@@ -119,6 +122,7 @@ gnc_html_webkit_init( GncHtmlWebkit* self )
 
     WebKitWebSettings* webkit_settings = NULL;
     const char* default_font_family = NULL;
+    gdouble zoom = 1.0;
 
     new_priv = g_realloc( GNC_HTML(self)->priv, sizeof(GncHtmlWebkitPrivate) );
     priv = self->priv = new_priv;
@@ -127,6 +131,7 @@ gnc_html_webkit_init( GncHtmlWebkit* self )
     priv->html_string = NULL;
     priv->web_view = WEBKIT_WEB_VIEW(webkit_web_view_new());
 
+
     /* Get the default font family from GtkStyle of a GtkWidget(priv-web_view). */
     default_font_family = pango_font_description_get_family( gtk_rc_get_style(GTK_WIDGET(priv->web_view))->font_desc );
 
@@ -144,6 +149,11 @@ gnc_html_webkit_init( GncHtmlWebkit* self )
                       NULL);
         PINFO("webkit_settings: Set default font to [%s]", default_font_family);
     }
+    /* Scale everything up */
+    zoom = gnc_prefs_get_float (GNC_PREFS_GROUP_GENERAL_REPORT, GNC_PREF_RPT_DFLT_ZOOM);
+    webkit_web_view_set_full_content_zoom (priv->web_view, TRUE);
+    webkit_web_view_set_zoom_level (priv->web_view, zoom);
+
 
     gtk_container_add( GTK_CONTAINER(priv->base.container),
                        GTK_WIDGET(priv->web_view) );
@@ -181,6 +191,11 @@ gnc_html_webkit_init( GncHtmlWebkit* self )
                       self);
 #endif
 
+    gnc_prefs_register_cb (GNC_PREFS_GROUP_GENERAL_REPORT,
+            GNC_PREF_RPT_DFLT_ZOOM,
+            impl_webkit_default_zoom_changed,
+                           self);
+
     LEAVE("retval %p", self);
 }
 
@@ -222,6 +237,11 @@ gnc_html_webkit_dispose( GObject* obj )
         priv->html_string = NULL;
     }
 
+    gnc_prefs_remove_cb_by_func (GNC_PREFS_GROUP_GENERAL_REPORT,
+            GNC_PREF_RPT_DFLT_ZOOM,
+            impl_webkit_default_zoom_changed,
+                                 obj);
+
     G_OBJECT_CLASS(gnc_html_webkit_parent_class)->dispose( obj );
 }
 
@@ -724,12 +744,10 @@ static void
 impl_webkit_show_data( GncHtml* self, const gchar* data, int datalen )
 {
     GncHtmlWebkitPrivate* priv;
-#if HAVE(WEBKIT_WEB_VIEW_LOAD_URI)
 #define TEMPLATE_REPORT_FILE_NAME "gnc-report-XXXXXX.html"
     int fd;
     gchar* uri;
     gchar *filename;
-#endif
 
     g_return_if_fail( self != NULL );
     g_return_if_fail( GNC_IS_HTML_WEBKIT(self) );
@@ -738,7 +756,6 @@ impl_webkit_show_data( GncHtml* self, const gchar* data, int datalen )
 
     priv = GNC_HTML_WEBKIT_GET_PRIVATE(self);
 
-#if HAVE(WEBKIT_WEB_VIEW_LOAD_URI)
     /* Export the HTML to a file and load the file URI.   On Linux, this seems to get around some
        security problems (otherwise, it can complain that embedded images aren't permitted to be
        viewed because they are local resources).  On Windows, this allows the embedded images to
@@ -753,9 +770,6 @@ impl_webkit_show_data( GncHtml* self, const gchar* data, int datalen )
     DEBUG("Loading uri '%s'", uri);
     webkit_web_view_load_uri( priv->web_view, uri );
     g_free( uri );
-#else
-    webkit_web_view_load_html_string( priv->web_view, data, BASE_URI_NAME );
-#endif
 
     LEAVE("");
 }
@@ -959,17 +973,16 @@ impl_webkit_show_url( GncHtml* self, URLType type,
 static void
 impl_webkit_reload( GncHtml* self, gboolean force_rebuild )
 {
-    gnc_html_history_node * n;
     GncHtmlWebkitPrivate* priv;
 
     g_return_if_fail( self != NULL );
     g_return_if_fail( GNC_IS_HTML_WEBKIT(self) );
 
     priv = GNC_HTML_WEBKIT_GET_PRIVATE(self);
-    n = gnc_html_history_get_current( priv->base.history );
 
     if ( force_rebuild )
     {
+        gnc_html_history_node *n = gnc_html_history_get_current( priv->base.history );
         if ( n != NULL )
             gnc_html_show_url( self, n->type, n->location, n->label, 0 );
     }
@@ -1039,7 +1052,7 @@ impl_webkit_copy_to_clipboard( GncHtml* self )
  *
  * @param self GncHtmlWebkit object
  * @param filepath Where to write the HTML
- * @return TRUE if successful, FALSE if unsucessful
+ * @return TRUE if successful, FALSE if unsuccessful
  **************************************************************/
 static gboolean
 impl_webkit_export_to_file( GncHtml* self, const char *filepath )
@@ -1093,23 +1106,16 @@ impl_webkit_export_to_file( GncHtml* self, const char *filepath )
 static void
 impl_webkit_print( GncHtml* self, const gchar* jobname, gboolean export_pdf )
 {
-#if !HAVE(WEBKIT_WEB_FRAME_PRINT_FULL)
-    extern void webkit_web_frame_print( WebKitWebFrame * frame );
-#endif
-
     gchar *export_filename = NULL;
     GncHtmlWebkitPrivate* priv;
     WebKitWebFrame* frame;
-#if HAVE(WEBKIT_WEB_FRAME_PRINT_FULL)
     GtkPrintOperation* op = gtk_print_operation_new();
     GError* error = NULL;
     GtkPrintSettings *print_settings;
-#endif
 
     priv = GNC_HTML_WEBKIT_GET_PRIVATE(self);
     frame = webkit_web_view_get_main_frame( priv->web_view );
 
-#if HAVE(WEBKIT_WEB_FRAME_PRINT_FULL)
     gnc_print_operation_init( op, jobname );
     print_settings = gtk_print_operation_get_print_settings (op);
     if (!print_settings)
@@ -1284,10 +1290,6 @@ impl_webkit_print( GncHtml* self, const gchar* jobname, gboolean export_pdf )
     gnc_print_operation_save_print_settings(op);
     g_object_unref( op );
     g_free(export_filename);
-
-#else
-    webkit_web_frame_print( frame );
-#endif
 }
 
 static void
@@ -1301,3 +1303,17 @@ impl_webkit_set_parent( GncHtml* self, GtkWindow* parent )
     priv = GNC_HTML_WEBKIT_GET_PRIVATE(self);
     priv->base.parent = GTK_WIDGET(parent);
 }
+
+static void
+impl_webkit_default_zoom_changed(gpointer prefs, gchar *pref, gpointer user_data)
+{
+    gdouble zoom = 1.0;
+    GncHtmlWebkit* self = GNC_HTML_WEBKIT(user_data);
+    GncHtmlWebkitPrivate* priv = GNC_HTML_WEBKIT_GET_PRIVATE(self);
+
+    g_return_if_fail(user_data != NULL);
+
+    zoom = gnc_prefs_get_float (GNC_PREFS_GROUP_GENERAL_REPORT, GNC_PREF_RPT_DFLT_ZOOM);
+    webkit_web_view_set_zoom_level (priv->web_view, zoom);
+
+}
