@@ -33,15 +33,19 @@
 
 #include "import-backend.h"
 #include "import-match-picker.h"
+#include "import-pending-matches.h"
 
 #include "qof.h"
 #include "gnc-ui-util.h"
 #include "dialog-utils.h"
+#include "gnc-prefs.h"
+
 /********************************************************************\
  *   Constants   *
 \********************************************************************/
 
 #define GNC_PREFS_GROUP "dialogs.import.generic.match-picker"
+#define GNC_PREF_DISPLAY_RECONCILED "display-reconciled"
 
 enum downloaded_cols
 {
@@ -63,6 +67,8 @@ enum matcher_cols
     MATCHER_COL_AMOUNT,
     MATCHER_COL_DESCRIPTION,
     MATCHER_COL_MEMO,
+    MATCHER_COL_RECONCILED,
+    MATCHER_COL_PENDING,
     MATCHER_COL_INFO_PTR,
     NUM_MATCHER_COLS
 };
@@ -85,9 +91,11 @@ struct _transpickerdialog
     GtkWidget * transaction_matcher;
     GtkTreeView * downloaded_view;
     GtkTreeView * match_view;
+    GtkCheckButton * reconciled_chk;
     GNCImportSettings * user_settings;
     struct _transactioninfo * selected_trans_info;
     GNCImportMatchInfo * selected_match_info;
+    GNCImportPendingMatches * pending_matches;
 };
 
 
@@ -171,34 +179,21 @@ downloaded_transaction_append(GNCImportMatchPicker * matcher,
     gtk_tree_selection_select_iter(selection, &iter);
 }
 
-/********************************************************************\
- *                                                                   *
- *                       GUI callbacks                               *
- *                                                                   *
-\********************************************************************/
-
 static void
-downloaded_transaction_changed_cb (GtkTreeSelection *selection,
-                                   GNCImportMatchPicker *matcher)
+match_update_match_model (GNCImportMatchPicker *matcher)
 {
     GNCImportMatchInfo * match_info;
-    GtkTreeModel *dl_model;
-    GtkListStore *match_store;
     GtkTreeIter iter;
+    gboolean show_reconciled;
+    gchar reconciled;
+    GtkListStore *match_store;
     GList * list_element;
     gchar *text;
     const gchar *ro_text;
-    /*DEBUG("row: %d%s%d",row,", column: ",column);*/
+    GNCImportPendingMatchType pending_match_type;
 
-    /* Get the transaction info from the "downloaded" model.  */
-    if (!gtk_tree_selection_get_selected(selection, &dl_model, &iter))
-    {
-        matcher->selected_trans_info = NULL;
-        return;
-    }
-    gtk_tree_model_get(dl_model, &iter,
-                       DOWNLOADED_COL_INFO_PTR, &matcher->selected_trans_info,
-                       -1);
+    show_reconciled = gtk_toggle_button_get_active
+                        (GTK_TOGGLE_BUTTON(matcher->reconciled_chk));
 
     /* Now rewrite the "match" model based on that trans. */
     match_store = GTK_LIST_STORE(gtk_tree_view_get_model(matcher->match_view));
@@ -209,6 +204,15 @@ downloaded_transaction_changed_cb (GtkTreeSelection *selection,
     {
         match_info = list_element->data;
 
+        /* Skip this match if reconciled and we're not showing those */
+        reconciled = xaccSplitGetReconcile
+                        (gnc_import_MatchInfo_get_split(match_info));
+        if (show_reconciled == FALSE && reconciled != NREC)
+        {
+            list_element = g_list_next (list_element);
+            continue;
+        }
+
         gtk_list_store_append(match_store, &iter);
 
         /* Print fields. */
@@ -243,27 +247,38 @@ downloaded_transaction_changed_cb (GtkTreeSelection *selection,
         ro_text = xaccSplitGetMemo(gnc_import_MatchInfo_get_split(match_info) );
         gtk_list_store_set(match_store, &iter, MATCHER_COL_MEMO, ro_text, -1);
 
+        /*Reconciled*/
+        ro_text = gnc_get_reconcile_str (reconciled);
+        gtk_list_store_set (match_store, &iter, MATCHER_COL_RECONCILED, ro_text,
+                            -1);
+        
+        /*Pending Action*/
+        pending_match_type = gnc_import_PendingMatches_get_match_type
+                                 (matcher->pending_matches, match_info);
+        
+        /* If it has a pending match mark it cleared, otherwise leave alone */
+        if (pending_match_type == GNCImportPending_MANUAL ||
+            pending_match_type == GNCImportPending_AUTO)
+        {
+            ro_text = gnc_get_reconcile_str (CREC);
+            text = g_strdup_printf("%s (%s)",
+                                   ro_text,
+                                   gnc_import_PendingMatches_get_type_str
+                                       (pending_match_type));
+            
+            gtk_list_store_set (match_store, &iter, MATCHER_COL_PENDING, text, -1);
+            g_free (text);
+        }
+
         gtk_list_store_set(match_store, &iter, MATCHER_COL_INFO_PTR, match_info, -1);
         if (gnc_import_MatchInfo_get_probability(match_info) != 0)
         {
-            if (SHOW_NUMERIC_SCORE == TRUE)
-            {
                 gtk_list_store_set(match_store, &iter,
                                    MATCHER_COL_CONFIDENCE_PIXBUF,
                                    gen_probability_pixbuf(gnc_import_MatchInfo_get_probability(match_info),
                                            matcher->user_settings,
                                            GTK_WIDGET(matcher->match_view)),
                                    -1);
-            }
-            else
-            {
-                gtk_list_store_set(match_store, &iter,
-                                   MATCHER_COL_CONFIDENCE_PIXBUF,
-                                   gen_probability_pixbuf(gnc_import_MatchInfo_get_probability(match_info),
-                                           matcher->user_settings,
-                                           GTK_WIDGET(matcher->match_view)),
-                                   -1);
-            }
         }
 
         if (match_info ==
@@ -279,6 +294,40 @@ downloaded_transaction_changed_cb (GtkTreeSelection *selection,
     }
 }
 
+/********************************************************************\
+ *                                                                   *
+ *                       GUI callbacks                               *
+ *                                                                   *
+\********************************************************************/
+
+static void
+downloaded_transaction_changed_cb (GtkTreeSelection *selection,
+                                   GNCImportMatchPicker *matcher)
+{
+    GtkTreeModel *dl_model;
+    GtkTreeIter iter;
+    /*DEBUG("row: %d%s%d",row,", column: ",column);*/
+
+    /* Get the transaction info from the "downloaded" model.  */
+    if (!gtk_tree_selection_get_selected(selection, &dl_model, &iter))
+    {
+        matcher->selected_trans_info = NULL;
+        return;
+    }
+    gtk_tree_model_get(dl_model, &iter,
+                       DOWNLOADED_COL_INFO_PTR, &matcher->selected_trans_info,
+                       -1);
+
+    match_update_match_model (matcher);
+}
+
+static void
+match_show_reconciled_changed_cb (GtkCheckButton* checkbox,
+                                  GNCImportMatchPicker *matcher)
+{
+    match_update_match_model (matcher);
+}
+
 static void
 match_transaction_changed_cb (GtkTreeSelection *selection,
                               GNCImportMatchPicker *matcher)
@@ -365,7 +414,7 @@ gnc_import_match_picker_init_match_view (GNCImportMatchPicker * matcher)
     store = gtk_list_store_new(NUM_MATCHER_COLS,
                                G_TYPE_STRING, GDK_TYPE_PIXBUF, G_TYPE_STRING,
                                G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
-                               G_TYPE_POINTER);
+                               G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER);
     gtk_tree_view_set_model(view, GTK_TREE_MODEL(store));
     g_object_unref(store);
 
@@ -381,10 +430,12 @@ gnc_import_match_picker_init_match_view (GNCImportMatchPicker * matcher)
                                         NULL);
     gtk_tree_view_append_column(view, column);
 
-    add_column(view, _("Date"),        MATCHER_COL_DATE);
-    add_column(view, _("Amount"),      MATCHER_COL_AMOUNT);
-    add_column(view, _("Description"), MATCHER_COL_DESCRIPTION);
-    add_column(view, _("Memo"),        MATCHER_COL_MEMO);
+    add_column(view, _("Date"),           MATCHER_COL_DATE);
+    add_column(view, _("Amount"),         MATCHER_COL_AMOUNT);
+    add_column(view, _("Description"),    MATCHER_COL_DESCRIPTION);
+    add_column(view, _("Memo"),           MATCHER_COL_MEMO);
+    add_column(view, _("Reconciled"),     MATCHER_COL_RECONCILED);
+    add_column(view, _("Pending Action"), MATCHER_COL_PENDING);
 
     selection = gtk_tree_view_get_selection(view);
     g_signal_connect(selection, "changed",
@@ -401,6 +452,7 @@ static void
 init_match_picker_gui(GNCImportMatchPicker * matcher)
 {
     GtkBuilder *builder;
+    gboolean show_reconciled;
 
     /* DEBUG("Begin..."); */
 
@@ -415,6 +467,10 @@ init_match_picker_gui(GNCImportMatchPicker * matcher)
     matcher->transaction_matcher = GTK_WIDGET(gtk_builder_get_object (builder, "match_picker"));
     matcher->downloaded_view = (GtkTreeView *)GTK_WIDGET(gtk_builder_get_object (builder, "download_view"));
     matcher->match_view = (GtkTreeView *)GTK_WIDGET(gtk_builder_get_object (builder, "matched_view"));
+    matcher->reconciled_chk = (GtkCheckButton *)GTK_WIDGET(gtk_builder_get_object(builder, "hide_reconciled_check1"));
+    
+    gnc_prefs_bind (GNC_PREFS_GROUP, GNC_PREF_DISPLAY_RECONCILED,
+                    matcher->reconciled_chk, "active");
 
     gnc_import_match_picker_init_downloaded_view(matcher);
     gnc_import_match_picker_init_match_view(matcher);
@@ -425,7 +481,15 @@ init_match_picker_gui(GNCImportMatchPicker * matcher)
        ", clear_threshold:",matcher->clear_threshold,
        ", add_threshold:",matcher->add_threshold,
        ", display_threshold:",matcher->display_threshold); */
+    
+    /* now that we've bound the checkbox appropriately we can hook up the
+     * change callback */
+    gtk_signal_connect ((GtkObject *)matcher->reconciled_chk, "toggled",
+                       G_CALLBACK(match_show_reconciled_changed_cb), matcher);
 
+    /* now that we've bound the checkbox appropriately we can hook up the change callback */
+    gtk_signal_connect((GtkObject *)matcher->reconciled_chk, "toggled", G_CALLBACK(match_show_reconciled_changed_cb), matcher);
+    
     gnc_restore_window_size(GNC_PREFS_GROUP,
                             GTK_WINDOW (matcher->transaction_matcher));
     gtk_widget_show(matcher->transaction_matcher);
@@ -440,28 +504,36 @@ init_match_picker_gui(GNCImportMatchPicker * matcher)
  * return after the user clicked Ok, Cancel, or Window-Close.
  */
 void
-gnc_import_match_picker_run_and_close (GNCImportTransInfo *transaction_info)
+gnc_import_match_picker_run_and_close (GNCImportTransInfo *transaction_info,
+                                       GNCImportPendingMatches *pending_matches)
 {
     GNCImportMatchPicker *matcher;
     gint response;
     GNCImportMatchInfo *old;
+    gboolean old_selected_manually;
     g_assert (transaction_info);
 
     /* Create a new match_picker, even though it's stored in a
        transmatcher struct :-) */
     matcher = g_new0(GNCImportMatchPicker, 1);
+    
+    matcher->pending_matches = pending_matches;
+    
     /* DEBUG("Init match_picker"); */
     init_match_picker_gui(matcher);
 
     /* Append this single transaction to the view and select it */
     downloaded_transaction_append(matcher, transaction_info);
 
-    old = gnc_import_TransInfo_get_selected_match(transaction_info);
+    old = gnc_import_TransInfo_get_selected_match (transaction_info);
+    old_selected_manually = 
+        gnc_import_TransInfo_get_match_selected_manually (transaction_info);
 
     /* Let this dialog run and close. */
     /*DEBUG("Right before run and close");*/
     gtk_window_set_modal(GTK_WINDOW(matcher->transaction_matcher), TRUE);
     response = gtk_dialog_run (GTK_DIALOG (matcher->transaction_matcher));
+    
     gnc_save_window_size(GNC_PREFS_GROUP,
                          GTK_WINDOW (matcher->transaction_matcher));
     gtk_widget_destroy (matcher->transaction_matcher);
@@ -470,9 +542,16 @@ gnc_import_match_picker_run_and_close (GNCImportTransInfo *transaction_info)
     if (response == GTK_RESPONSE_OK && matcher->selected_match_info != old)
     {
         /* OK was pressed */
-        gnc_import_TransInfo_set_selected_match (transaction_info,
+        gnc_import_TransInfo_set_selected_match_info (transaction_info,
                 matcher->selected_match_info,
                 TRUE);
+        
+        gnc_import_PendingMatches_remove_match (pending_matches,
+                                                old,
+                                                old_selected_manually);
+        gnc_import_PendingMatches_add_match (pending_matches,
+                                             matcher->selected_match_info,
+                                             TRUE);
     }
 }
 
