@@ -16,10 +16,10 @@ book = ses.get_book()
 
 #Call some methods that produce output to show that Book works
 book.get_root_account().SetDescription("hello, book")
-print "Book is saved:", not book.not_saved()
+print "Book is saved:", not book.session_not_saved()
 
 print "saving..."
 ses.save()
 
-print "Book is saved:", not book.not_saved()
+print "Book is saved:", not book.session_not_saved()
 ses.end()
