@@ -6,8 +6,8 @@ class BookSession( TestCase ):
     def setUp(self):
         self.ses = Session()
         self.book = self.ses.get_book()
-        table = self.book.get_table()
-        self.currency = table.lookup('CURRENCY', 'EUR')
+        self.table = self.book.get_table()
+        self.currency = self.table.lookup('CURRENCY', 'EUR')
 
 class TestBook( BookSession ):
     def test_markclosed(self):
