@@ -414,7 +414,7 @@ gnc_ledger_display2_gl (void)
 
     /* In lieu of not "mis-using" some portion of the infrastructure by writing
      * a bunch of new code, we just filter out the accounts of the template
-     * transactions.  While these are in a seperate Account trees just for this
+     * transactions.  While these are in a separate Account trees just for this
      * reason, the query engine makes no distinction between Account trees.
      * See Gnome Bug 86302.
      *         -- jsled */
@@ -424,7 +424,10 @@ gnc_ledger_display2_gl (void)
 
         tRoot = gnc_book_get_template_root( gnc_get_current_book() );
         al = gnc_account_get_descendants( tRoot );
-        xaccQueryAddAccountMatch( query, al, QOF_GUID_MATCH_NONE, QOF_QUERY_AND );
+
+        if (g_list_length(al) != 0)
+            xaccQueryAddAccountMatch( query, al, QOF_GUID_MATCH_NONE, QOF_QUERY_AND );
+
         g_list_free (al);
         al = NULL;
         tRoot = NULL;
@@ -698,7 +701,7 @@ gnc_ledger_display2_internal (Account *lead_account, Query *q,
 {
     GNCLedgerDisplay2 *ld;
     gint limit;
-    const char *class;
+    const char *klass;
     GList *splits;
     gboolean display_subaccounts = FALSE;
     gboolean is_gl = FALSE;
@@ -706,7 +709,7 @@ gnc_ledger_display2_internal (Account *lead_account, Query *q,
     switch (ld_type)
     {
     case LD2_SINGLE:
-        class = REGISTER_SINGLE_CM_CLASS;
+        klass = REGISTER_SINGLE_CM_CLASS;
 
         if (reg_type >= NUM_SINGLE_REGISTER_TYPES2)
         {
@@ -726,14 +729,14 @@ gnc_ledger_display2_internal (Account *lead_account, Query *q,
             q = NULL;
         }
 
-        ld = gnc_find_first_gui_component (class, find_by_leader, lead_account);
+        ld = gnc_find_first_gui_component (klass, find_by_leader, lead_account);
         if (ld)
             return ld;
 
         break;
 
     case LD2_SUBACCOUNT:
-        class = REGISTER_SUBACCOUNT_CM_CLASS;
+        klass = REGISTER_SUBACCOUNT_CM_CLASS;
 
         if (!lead_account)
         {
@@ -747,7 +750,7 @@ gnc_ledger_display2_internal (Account *lead_account, Query *q,
             q = NULL;
         }
 
-        ld = gnc_find_first_gui_component (class, find_by_leader, lead_account);
+        ld = gnc_find_first_gui_component (klass, find_by_leader, lead_account);
         if (ld)
             return ld;
 
@@ -755,7 +758,7 @@ gnc_ledger_display2_internal (Account *lead_account, Query *q,
         break;
 
     case LD2_GL:
-        class = REGISTER_GL_CM_CLASS;
+        klass = REGISTER_GL_CM_CLASS;
 
         if (!q)
         {
@@ -790,7 +793,7 @@ gnc_ledger_display2_internal (Account *lead_account, Query *q,
     else
         gnc_ledger_display2_make_query (ld, limit, reg_type);
 
-    ld->component_id = gnc_register_gui_component (class,
+    ld->component_id = gnc_register_gui_component (klass,
                        refresh_handler,
                        close_handler, ld);
 
