@@ -634,6 +634,11 @@ gnc_split_register_layout_add_cells (SplitRegister *reg,
     gnc_register_add_cell (layout,
                            DATE_CELL,
                            DATE_CELL_TYPE_NAME,
+                           /* Translators: The 'sample:' items are
+                              strings which are not displayed, but only
+                              used to estimate widths. Please only
+                              translate the portion after the ':' and
+                              leave the rest ("sample:") as is. */
                            N_("sample:12/12/2000") + 7,
                            CELL_ALIGN_RIGHT,
                            FALSE,
@@ -687,7 +692,11 @@ gnc_split_register_layout_add_cells (SplitRegister *reg,
     gnc_register_add_cell (layout,
                            RECN_CELL,
                            RECN_CELL_TYPE_NAME,
-                           N_("Reconciled:R") + 11,
+	                          /* Translators: The abbreviation for 'Reconciled'
+	                              in the header row of the register. Please only
+	                              translate the portion after the ':' and
+	                              leave the rest ("Reconciled:") as is. */
+	                            N_("Reconciled:R") + 11,
                            CELL_ALIGN_CENTER,
                            FALSE,
                            FALSE);
@@ -695,6 +704,10 @@ gnc_split_register_layout_add_cells (SplitRegister *reg,
     gnc_register_add_cell (layout,
                            ASSOC_CELL,
                            RECN_CELL_TYPE_NAME,
+                           /* Translators: The abbreviation for 'Associate'
+                              in the header row of the register. Please only
+                              translate the portion after the ':' and
+                              leave the rest ("Associate:") as is. */
                            N_("Associate:A") + 10,
                            CELL_ALIGN_CENTER,
                            FALSE,
@@ -809,7 +822,11 @@ gnc_split_register_layout_add_cells (SplitRegister *reg,
     gnc_register_add_cell (layout,
                            TYPE_CELL,
                            RECN_CELL_TYPE_NAME,
-                           N_("Type:T") + 5,
+	                          /* Translators: The abbreviation for 'Type'
+	                              in the header row of the register. Please only
+	                              translate the portion after the ':' and
+	                              leave the rest ("Type:") as is. */
+	                            N_("Type:T") + 5,
                            CELL_ALIGN_CENTER,
                            FALSE,
                            FALSE);
