@@ -67,6 +67,24 @@ gnc_split_register_load_recn_cells (SplitRegister *reg)
     gnc_recn_cell_set_string_getter (cell, gnc_get_reconcile_str);
 }
 
+static void
+gnc_split_register_load_associate_cells (SplitRegister *reg)
+{
+    RecnCell *cell;
+
+    if (!reg) return;
+
+    cell = (RecnCell *)
+           gnc_table_layout_get_cell (reg->table->layout, ASSOC_CELL);
+
+    if (!cell) return;
+
+    /* FIXME: These should get moved to an i18n function */
+    gnc_recn_cell_set_valid_flags (cell, "fw ", ' ');
+    gnc_recn_cell_set_flag_order (cell, "fw ");
+    gnc_recn_cell_set_read_only (cell, TRUE);
+}
+
 static void
 gnc_split_register_load_type_cells (SplitRegister *reg)
 {
@@ -487,6 +505,7 @@ gnc_split_register_load (SplitRegister *reg, GList * slist,
 
         /* load up account names into the transfer combobox menus */
         gnc_split_register_load_xfer_cells (reg, default_account);
+        gnc_split_register_load_associate_cells (reg);
         gnc_split_register_load_recn_cells (reg);
         gnc_split_register_load_type_cells (reg);
     }
