@@ -155,12 +155,11 @@
               (begin 
                 ;;This is the only place where <html> appears
                 ;;with the exception of 2 reports: 
-                ;;./share/gnucash/guile-modules/gnucash/report/taxinvoice.eguile.scm:<html>
-                ;;./share/gnucash/guile-modules/gnucash/report/balsheet-eg.eguile.scm:<html>
+                ;;./share/gnucash/scm/gnucash/report/taxinvoice.eguile.scm:<html>
+                ;;./share/gnucash/scm/gnucash/report/balsheet-eg.eguile.scm:<html>
 
-                ;; Validate against XHTML 1.0 Transitional
-                (push "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \n\"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">")
-                (push "<html xmlns=\"http://www.w3.org/1999/xhtml\">\n")
+                ;; Validate against HTML4 Transitional:
+                (push "<!DOCTYPE html PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \n\"http://www.w3.org/TR/html4/loose.dtd\">")
                 (push "<head>\n")
                 (push "<meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\" />\n")
 				(if css? 
@@ -169,7 +168,7 @@
                 (let ((title (gnc:html-document-title doc)))
                   (if title 
                       (push (list "</title>" title "<title>\n"))))
-                (push "</head>\n")
+                (push "</head>")
                 
                 ;; this lovely little number just makes sure that <body>
                 ;; attributes like bgcolor get included 
@@ -287,7 +286,7 @@
                       (attr (gnc:warn "non-string attribute" attr)))))
              (build-first-tag
               (lambda (tag)
-                (push "\n<") (push tag)
+                (push "<") (push tag)
                 (if attr (hash-fold add-attribute #f attr))
                 (if extra-attrib (for-each addextraatt extra-attrib))
                 (if (not end-tag?)
@@ -396,7 +395,7 @@
                (lambda (obj doc)
                  (gnc:html-document-render-data doc obj))
                ;; if the object is #f, make it a placeholder
-               (if obj obj "&nbsp;&nbsp;&nbsp;")))        
+               (if obj obj " ")))        
         (cond 
          ((gnc:html-text? obj)
           (set! o (gnc:make-html-object-internal 
