@@ -4,6 +4,25 @@
 ;;
 ;;  Copyright (c) 2001 Linux Developers Group, Inc.
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; This program is free software; you can redistribute it and/or
+;; modify it under the terms of the GNU General Public License as
+;; published by the Free Software Foundation; either version 2 of
+;; the License, or (at your option) any later version.
+;;
+;; This program is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;;
+;; You should have received a copy of the GNU General Public License
+;; along with this program; if not, contact:
+;;
+;; Free Software Foundation           Voice:  +1-617-542-5942
+;; 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652
+;; Boston, MA  02110-1301,  USA       gnu@gnu.org
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
 
 (define-module (gnucash report report-system))
 (use-modules (gnucash main)) ;; FIXME: delete after we finish modularizing.
@@ -109,10 +128,12 @@
 (export gnc:menuname-taxes)
 (export gnc:menuname-utility)
 (export gnc:menuname-custom)
+(export gnc:menuname-business-reports)
 (export gnc:pagename-general)
 (export gnc:pagename-accounts)
 (export gnc:pagename-display)
 (export gnc:optname-reportname)
+(export gnc:optname-invoice-number)
 
 (export gnc:define-report)
 (export <report>)
@@ -509,9 +530,9 @@
 (export gnc:html-acct-table-set-cell!)
 (export gnc:html-acct-table-get-row-env)
 (export gnc:html-acct-table-set-row-env!)
-(export gnc:html-acct-table-append-row)
+(export gnc:html-acct-table-append-row!)
 (export gnc:html-acct-table-prepend-row!)
-(export gnc:html-acct-table-append-col)
+(export gnc:html-acct-table-append-col!)
 (export gnc:html-acct-table-prepend-col!)
 (export gnc:html-acct-table-remove-last-row!)
 (export gnc:html-acct-table-render)
@@ -646,7 +667,6 @@
 (export gnc:account-get-type-string-plural)
 (export gnc:accounts-get-commodities)
 (export gnc:get-current-account-tree-depth)
-(export gnc:split-get-corr-account-full-name)
 (export gnc:acccounts-get-all-subaccounts)
 (export gnc:make-stats-collector)
 (export gnc:make-drcr-collector)
@@ -700,22 +720,22 @@
 (export gnc:get-assoc-account-balances-total)
 (export make-file-url)
 
-(load-from-path "commodity-utilities.scm")
-(load-from-path "html-barchart.scm")
-(load-from-path "html-document.scm")
-(load-from-path "html-piechart.scm")
-(load-from-path "html-scatter.scm")
-(load-from-path "html-linechart.scm")
-(load-from-path "html-style-info.scm")
-(load-from-path "html-fonts.scm")
+(load-from-path "commodity-utilities")
+(load-from-path "html-barchart")
+(load-from-path "html-document")
+(load-from-path "html-piechart")
+(load-from-path "html-scatter")
+(load-from-path "html-linechart")
+(load-from-path "html-style-info")
+(load-from-path "html-fonts")
 
-(load-from-path "html-style-sheet.scm")
-(load-from-path "html-table.scm")
-(load-from-path "html-text.scm")
-(load-from-path "html-acct-table.scm")
-(load-from-path "html-utilities.scm")
-(load-from-path "options-utilities.scm")
-(load-from-path "report-utilities.scm")
-(load-from-path "report.scm")
+(load-from-path "html-style-sheet")
+(load-from-path "html-table")
+(load-from-path "html-text")
+(load-from-path "html-acct-table")
+(load-from-path "html-utilities")
+(load-from-path "options-utilities")
+(load-from-path "report-utilities")
+(load-from-path "report")
 
 (gnc-hook-add-scm-dangler HOOK-SAVE-OPTIONS gnc:save-style-sheet-options)
