@@ -1,4 +1,23 @@
 ;; -*-scheme-*-
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; This program is free software; you can redistribute it and/or
+;; modify it under the terms of the GNU General Public License as
+;; published by the Free Software Foundation; either version 2 of
+;; the License, or (at your option) any later version.
+;;
+;; This program is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;;
+;; You should have received a copy of the GNU General Public License
+;; along with this program; if not, contact:
+;;
+;; Free Software Foundation           Voice:  +1-617-542-5942
+;; 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652
+;; Boston, MA  02110-1301,  USA       gnu@gnu.org
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
 
 ;; This is a sample guile report generator for GnuCash.
 ;; It illustrates the basic techniques used to create
@@ -7,8 +26,13 @@
 (define-module (gnucash report hello-world))
 (use-modules (gnucash main)) ;; FIXME: delete after we finish modularizing.
 (use-modules (gnucash gnc-module))
+(use-modules (gnucash gettext))
 
-(debug-enable 'debug)
+;; 'debug is deprecated and unused since guile 2
+(cond-expand
+  (guile-2 )
+  (else
+    (debug-enable 'debug)))
 (debug-enable 'backtrace)
 
 (gnc:module-load "gnucash/report/report-system" 0)
@@ -249,12 +273,12 @@ option like this.")
     ;; these are samples of different date options. for a simple
     ;; date with day, month, and year but no time you should use
     ;; gnc-print-date
-    (let ((time-string (strftime "%X" (localtime (current-time))))
-          (date-string (strftime "%x" (localtime (car date-val))))
-          (date-string2 (strftime "%x %X" (localtime (car date2-val))))
-          (rel-date-string (strftime "%x" (localtime (car rel-date-val))))
+    (let ((time-string (strftime "%X" (gnc-localtime (current-time))))
+          (date-string (strftime "%x" (gnc-localtime (car date-val))))
+          (date-string2 (strftime "%x %X" (gnc-localtime (car date2-val))))
+          (rel-date-string (strftime "%x" (gnc-localtime (car rel-date-val))))
           (combo-date-string
-           (strftime "%x" (localtime (car combo-date-val)))))
+           (strftime "%x" (gnc-localtime (car combo-date-val)))))
 
       ;; Here's where we fill the report document with content.  We
       ;; do this by adding 'html objects' such as text, tables, and
